%global with_devel 0
%global with_bundled 1
%global with_debug 1
%global with_check 0

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider        github
%global provider_tld    com
%global project         projectatomic
%global repo            skopeo
# https://github.com/projectatomic/skopeo
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit0         ae64ff7084c8ba60275232740b79c1876f8a5256
%global shortcommit0    %(c=%{commit0}; echo ${c:0:7})
%global git0            https://%{import_path}

Name:           %{repo}
Epoch:          1
Version:        0.1.31
Release:        1.dev.git%{shortcommit0}%{?dist}
Summary:        Inspect Docker images and repositories on registries
License:        ASL 2.0
URL:            %{git0}
Source0:        %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1:        storage.conf
Source2:        containers-storage.conf.5.md
Source3:        mounts.conf
Source4:        registries.conf
Source5:        registries.conf.5.md
BuildRequires:  git
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang} >= 1.6.2
%if 0%{?rhel} > 7
BuildRequires: go-toolset-7-golang-bin
BuildRequires: go-toolset-7-runtime
%endif
BuildRequires:  go-md2man
BuildRequires:  gpgme-devel
BuildRequires:  libassuan-devel
BuildRequires:  btrfs-progs-devel
BuildRequires:  device-mapper-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(ostree-1)
Requires: %{name}-containers = %{epoch}:%{version}-%{release}

%description
Command line utility to inspect images and repositories directly on Docker
registries without the need to pull them

%package containers
Summary: Configuration files for working with image signature
# /etc/containers/registries.d/default.yaml has been moved from atomic to
# skopeo-containers
Conflicts: atomic <= 1:1.13.1-1
Conflicts: atomic-registries <= 1:1.22.1-2

%description containers
This package installs a default signature store configuration
policy under `/etc/containers/`.

%if 0%{?rhel} > 7
%{enable_gotoolset7}
%endif

%prep
%autosetup -Sgit -n %{name}-%{commit0}

%build
mkdir -p src/github.com/projectatomic
ln -s ../../../ src/github.com/projectatomic/%{name}

mkdir -p vendor/src
for v in vendor/*; do
    if test ${v} = vendor/src; then continue; fi
    if test -d ${v}; then
	mv ${v} vendor/src/
    fi
done

export GOPATH=$(pwd):$(pwd)/vendor:%{gopath}

%if ! 0%{?gobuild:1}
%define gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%endif

%gobuild -o %{name} ./cmd/%{name}

if test -f man/%{name}.1.md; then
    go-md2man -in man/%{name}.1.md -out %{name}.1
fi

go-md2man -in %{SOURCE2} -out containers-storage.conf.5
go-md2man -in %{SOURCE5} -out registries.conf.5

%install
make DESTDIR=%{buildroot} install
install -m0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/containers/storage.conf
mkdir -p %{buildroot}%{_mandir}/man5
install -m644 containers-storage.conf.5 %{buildroot}%{_mandir}/man5
install -m644 registries.conf.5 %{buildroot}%{_mandir}/man5
mkdir -p %{buildroot}%{_datadir}/containers
install -m0644 %{SOURCE3} %{buildroot}%{_datadir}/containers/mounts.conf
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/containers/

# install secrets patch directory
install -d -p -m 750 %{buildroot}%{_datadir}/rhel/secrets
# rhbz#1110876 - update symlinks for subscription management
ln -s %{_sysconfdir}/pki/entitlement %{buildroot}%{_datadir}/rhel/secrets/etc-pki-entitlement
ln -s %{_sysconfdir}/rhsm %{buildroot}%{_datadir}/rhel/secrets/rhsm
ln -s %{_sysconfdir}/yum.repos.d/redhat.repo %{buildroot}%{_datadir}/rhel/secrets/rhel7.repo

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/vendor:%{gopath}
%gotest %{import_path}/integration
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files containers
%dir %{_sysconfdir}/containers
%dir %{_sysconfdir}/containers/registries.d
%config(noreplace) %{_sysconfdir}/containers/policy.json
%config(noreplace) %{_sysconfdir}/containers/registries.d/default.yaml
%config(noreplace) %{_sysconfdir}/containers/storage.conf
%config(noreplace) %{_sysconfdir}/containers/registries.conf
%dir %{_datadir}/containers
%{_datadir}/containers/mounts.conf
%dir %{_sharedstatedir}/atomic/sigstore
%{_mandir}/man5/*.conf.5*
%dir %{_datadir}/rhel/secrets
%{_datadir}/rhel/secrets/etc-pki-entitlement
%{_datadir}/rhel/secrets/rhel7.repo
%{_datadir}/rhel/secrets/rhsm

%files
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%license LICENSE
%doc README.md
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Mon Jul 16 2018 Johnny Hughes <johnny@centos.org> - 0.1.31-1.dev.gitae64ff7
- Manual CentOS Debranding

* Wed Jul 11 2018 Lokesh Mandvekar <lsm5@redhat.com> - 0.1.31-1.dev.gitae64ff7
- Resolves: #1599980, #1599224
- bump to v0.1.31-dev
- built commit ae64ff7

* Sun May 20 2018 dwalsh <dwalsh@redhat.com> - 0.1.30-14.gitca3bff6
- Add devicemapper support

* Tue Apr 10 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.29-3.git7add6fc
- move registries.conf to skopeo-containers from atomic

* Thu Mar 29 2018 dwalsh <dwalsh@redhat.com> - 0.1.29-2.git
- bump to 0.1.29-1
- Updated containers/image
    docker-archive generates docker legacy compatible images
    Do not create $DiffID subdirectories for layers with no configs
    Ensure the layer IDs in legacy docker/tarfile metadata are unique
    docker-archive: repeated layers are symlinked in the tar file
    sysregistries: remove all trailing slashes
    Improve docker/* error messages
    Fix failure to make auth directory
    Create a new slice in Schema1.UpdateLayerInfos
    Drop unused storageImageDestination.{image,systemContext}
    Load a *storage.Image only once in storageImageSource
    Support gzip for docker-archive files
    Remove .tar extension from blob and config file names
    ostree, src: support copy of compressed layers
    ostree: re-pull layer if it misses uncompressed_digest|uncompressed_size
    image: fix docker schema v1 -> OCI conversion
    Add /etc/containers/certs.d as default certs directory

* Wed Mar 21 2018 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.29-1.dev,gitb08350d
- Resolves: #1543707

* Thu Feb 01 2018 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.28-1.git0270e56
- rebased to 0.1.28

* Mon Dec 11 2017 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.27-3.dev.git14245f2
- rebased to 0.1.27-3.dev.git14245f2

* Thu Nov 16 2017 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.26-2.dev.git2e8377a
- bump changelog

* Wed Nov 15 2017 dwalsh <dwalsh@redhat.com> - 0.1.25-2.git2e8377a7
-  Add manifest type conversion to skopeo copy
-  User can select from 3 manifest types: oci, v2s1, or v2s2
-   e.g skopeo copy --format v2s1 --compress-blobs docker-archive:alp.tar dir:my-directory

* Wed Nov 8 2017 dwalsh <dwalsh@redhat.com> - 0.1.25-2.git7fd6f66b
- Force storage.conf to default to overlay

* Wed Nov 8 2017 dwalsh <dwalsh@redhat.com> - 0.1.25-1.git7fd6f66b
-   Fix CVE in tar-split
-   copy: add shared blob directory support for OCI sources/destinations
-   Aligning Docker version between containers/image and skopeo
-   Update image-tools, and remove the duplicate Sirupsen/logrus vendor
-   makefile: use -buildmode=pie

* Tue Nov 7 2017 dwalsh <dwalsh@redhat.com> - 1:0.1.24-8.git28d4e08a
- Add /usr/share/containers/mounts.conf

* Mon Oct 23 2017 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.24-5.gitdd2c3e3
- built commit dd2c3e3a8e33b849f3625f4f56fa229c76448629

* Thu Oct 19 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.24-3.dev.git28d4e08
- add rhel subscription secrets date to skopeo-containers
- skopeo-containers conflicts with docker >= 2:1.13.1-61

* Thu Oct 12 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.24-2.dev.git28d4e08
- Update container/storage.conf and containers-storage.conf man page
- Default override to true so it is consistent with RHEL.
 
* Fri Oct 06 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.24-1.dev.git28d4e08
- Resolves: #1499274
- built commit 28d4e08

* Mon Aug 07 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.23-1.git1bbd87f
- Resolves: #1455575, #1478416, #1387217
- bump to v0.1.23

* Fri Jun 30 2017 Ryan Hartman <rhartman@redhat.com> - 1:0.1.20-2.1.gite802625
- bump release to 2.1
- built commit e802625b7cb7f4af9ab77bd2be9eb441ff2f28a2

* Tue Jun 06 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.20-1.1.gite802625
- built commit e802625b7cb7f4af9ab77bd2be9eb441ff2f28a2

* Thu Mar 30 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.19-1.1.git62e3747
- bump to v0.1.19
- built commit 62e3747

* Thu Mar 30 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.18-1.2
- build for all available arches (previous build didn't do this)

* Mon Mar 27 2017 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.18-1.1
- rebuilt for all arches on extras 7.4
- enable debuginfo package

* Fri Feb 03 2017 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.18-1
- btrfs-progs-devel, device-mapper-devel added to build dependencies
- built commit b08008c

* Tue Dec 13 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.17-1
- Resolves: #1404274 - ship upstream v0.1.17 release
- built commit b3b4e2b

* Tue Nov 22 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.17-0.7.git1f655f3
- runtime dep was missing epoch value, added now

* Fri Nov 18 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.17-0.6.git1f655f3
- Resolves: #1396531 - list skopeo runtime requirements correctly

* Mon Oct 31 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.17-0.5
- built commit 1f655f3

* Tue Oct 18 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.17-0.4
- Resolves: #1386386 - skopeo-containers conflicts with atomic <= 1.13.1-1
- use correct bug number, #1385584 was for atomic

* Tue Oct 18 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.17-0.3
- Resolves: #1385584 - skopeo-containers conflicts with atomic <= 1.13.1-1

* Mon Oct 17 2016 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.17-0.2
- obsoletes atomic, fixed dependencies
- %{_sysconfdir}/containers/ owned only by skopeo-containers

* Fri Oct 14 2016 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.17-0.1
- rebase, skopeo-containers subpackage added

* Tue Sep 20 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.14-0.6
- built mtrmac/integrate-all-the-things commit d830391

* Fri Sep 16 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.14-0.5
- built mtrmac/integrate-all-the-things commit 85e4551

* Tue Sep 13 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.14-0.4
- built mtrmac/integrate-all-the-things commit 02b9f8b

* Tue Sep 13 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.14-0.3
- built mtrmac/integrate-all-the-things commit b3fcce0

* Tue Sep 06 2016 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.14-0.2.dev
- own the whole bash-completion dir (https://fedoraproject.org/wiki/Packaging:Guidelines)

* Tue Sep 06 2016 Frantisek Kluknavsky <fkluknav@redhat.com> - 1:0.1.14-0.1.dev
- update to 0.1.14-dev

* Tue Jul 26 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.13-8
- bump release, srpm issues in previous build

* Tue Jul 12 2016 Lokesh Mandvekar <lsm5@redhat.com> - 1:0.1.13-7
- build with golang >= 1.6.2

* Fri Jun 24 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1:0.1.13-6
- Bump Epoch to 1 since that's what skopeo had when it was an atomic
subpackage

* Tue Jun 21 2016 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.1.13-5
- include go-srpm-macros and compiler(go-compiler) in fedora conditionals
- define %%gobuild if not already
- add patch to build with older version of golang

* Thu Jun 02 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.13-4
- update to v0.1.12

* Tue May 31 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.12-3
- fix go build source path

* Fri May 27 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.12-2
- update to v0.1.12

* Tue Mar 08 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.11-1
- update to v0.1.11

* Tue Mar 08 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.10-1
- update to v0.1.10
- change runcom -> projectatomic

* Mon Feb 29 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.9-1
- update to v0.1.9

* Mon Feb 29 2016 Antonio Murdaca <runcom@fedoraproject.org> - 0.1.8-1
- update to v0.1.8

* Mon Feb 22 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.4-2
- https://fedoraproject.org/wiki/Changes/golang1.6

* Fri Jan 29 2016 Antonio Murdaca <runcom@redhat.com> - 0.1.4
- First package for Fedora
